==> fluxbb-1.4.2p0.tgz: fluxbb/lang/English/prof_reg.php <==
<?php

// Language definitions used in both profile.php and register.php
$lang_prof_reg = array(

'Email legend'				=>	'Enter a valid email address',
'Email legend 2'			=>	'Enter and confirm a valid email address',
'Localisation legend'		=>	'Set your localisation options',
'Time zone'					=>	'Time zone',
'Time zone info'			=>	'For the forum to display times correctly you must select your local time zone. If Daylight Savings Time is in effect you should also check the option provided which will advance times by 1 hour.',
'DST'						=>	'Daylight Savings Time is in effect (advance time by 1 hour).',
'Time format'				=>	'Time format',
'Date format'				=>	'Date format',
'Default'					=>	'Default',
'Language'					=>	'Language',
'Email setting info'		=>	'Select whether you want your email address to be viewable to other users or not and if you want other users to be able to send you email via the forum (form email) or not.',
'Email setting 1'			=>	'Display your email address.',
'Email setting 2'			=>	'Hide your email address but allow form email.',
'Email setting 3'			=>	'Hide your email address and disallow form email.',
'Privacy options legend'	=>	'Set your privacy options',
'Confirm pass'				=>	'Confirm password',

'Username too short'		=>	'Usernames must be at least 2 characters long. Please choose another (longer) username.',
'Username too long'			=>	'Usernames must not be more than 25 characters long. Please choose another (shorter) username.',
'Username guest'			=>	'The username guest is reserved. Please choose another username.',
'Username IP'				=>	'Usernames may not be in the form of an IP address. Please choose another username.',
'Username reserved chars'	=>	'Usernames may not contain all the characters \', " and [ or ] at once. Please choose another username.',
'Username BBCode'			=>	'Usernames may not contain any of the text formatting tags (BBCode) that the forum uses. Please choose another username.',
'Banned username'			=>	'The username you entered is banned in this forum. Please choose another username.',
'Pass too short'			=>	'Passwords must be at least 4 characters long. Please choose another (longer) password.',
'Pass not match'			=>	'Passwords do not match.',
'Banned email'				=>	'The email address you entered is banned in this forum. Please choose another email address.',
'Dupe email'				=>	'Someone else is already registered with that email address. Please choose another email address.',
'Sig too long'				=>	'Signatures cannot be longer than %1$s characters. Please reduce your signature by %2$s characters.',
'Sig too many lines'		=>	'Signatures cannot have more than %s lines.',
'Bad ICQ'					=>	'You entered an invalid ICQ UIN. Please go back and correct.',

'UTC-12:00'					=>	'(UTC-12:00) International Date Line West',
'UTC-11:00'					=>	'(UTC-11:00) Niue, Samoa',
'UTC-10:00'					=>	'(UTC-10:00) Hawaii-Aleutian, Cook Island',
'UTC-09:30'					=>	'(UTC-09:30) Marquesas Islands',
'UTC-09:00'					=>	'(UTC-09:00) Alaska, Gambier Island',
'UTC-08:30'					=>	'(UTC-08:30) Pitcairn Islands',
'UTC-08:00'					=>	'(UTC-08:00) Pacific',
'UTC-07:00'					=>	'(UTC-07:00) Mountain',
'UTC-06:00'					=>	'(UTC-06:00) Central',
'UTC-05:00'					=>	'(UTC-05:00) Eastern',
'UTC-04:00'					=>	'(UTC-04:00) Atlantic',
'UTC-03:30'					=>	'(UTC-03:30) Newfoundland',
'UTC-03:00'					=>	'(UTC-03:00) Amazon, Central Greenland',
'UTC-02:00'					=>	'(UTC-02:00) Mid-Atlantic',
'UTC-01:00'					=>	'(UTC-01:00) Azores, Cape Verde, Eastern Greenland',
'UTC'						=>	'(UTC) Western European, Greenwich',
'UTC+01:00'					=>	'(UTC+01:00) Central European, West African',
'UTC+02:00'					=>	'(UTC+02:00) Eastern European, Central African',
'UTC+03:00'					=>	'(UTC+03:00) Moscow, Eastern African',
'UTC+03:30'					=>	'(UTC+03:30) Iran',
'UTC+04:00'					=>	'(UTC+04:00) Gulf, Samara',
'UTC+04:30'					=>	'(UTC+04:30) Afghanistan',
'UTC+05:00'					=>	'(UTC+05:00) Pakistan, Yekaterinburg',
'UTC+05:30'					=>	'(UTC+05:30) India, Sri Lanka',
'UTC+05:45'					=>	'(UTC+05:45) Nepal',
'UTC+06:00'					=>	'(UTC+06:00) Bangladesh, Bhutan, Novosibirsk',
'UTC+06:30'					=>	'(UTC+06:30) Cocos Islands, Myanmar',
'UTC+07:00'					=>	'(UTC+07:00) Indochina, Krasnoyarsk',
'UTC+08:00'					=>	'(UTC+08:00) Greater China, Australian Western, Irkutsk',
'UTC+08:45'					=>	'(UTC+08:45) Southeastern Western Australia',
'UTC+09:00'					=>	'(UTC+09:00) Japan, Korea, Chita',
'UTC+09:30'					=>	'(UTC+09:30) Australian Central',
'UTC+10:00'					=>	'(UTC+10:00) Australian Eastern, Vladivostok',
'UTC+10:30'					=>	'(UTC+10:30) Lord Howe',
'UTC+11:00'					=>	'(UTC+11:00) Solomon Island, Magadan',
'UTC+11:30'					=>	'(UTC+11:30) Norfolk Island',
'UTC+12:00'					=>	'(UTC+12:00) New Zealand, Fiji, Kamchatka',
'UTC+12:45'					=>	'(UTC+12:45) Chatham Islands',
'UTC+13:00'					=>	'(UTC+13:00) Tonga, Phoenix Islands',
'UTC+14:00'					=>	'(UTC+14:00) Line Islands'

);

==> fluxbb-1.5.0p0.tgz: fluxbb/lang/English/prof_reg.php <==
<?php

// Language definitions used in both profile.php and register.php
$lang_prof_reg = array(

'Email legend'				=>	'Enter a valid email address',
'Email legend 2'			=>	'Enter and confirm a valid email address',
'Localisation legend'		=>	'Set your localisation options',
'Time zone'					=>	'Time zone',
'Time zone info'			=>	'For the forum to display times correctly you must select your local time zone. If Daylight Savings Time is in effect you should also check the option provided which will advance times by 1 hour.',
'DST'						=>	'Daylight Savings Time is in effect (advance time by 1 hour).',
'Time format'				=>	'Time format',
'Date format'				=>	'Date format',
'Default'					=>	'Default',
'Language'					=>	'Language',
'Email setting info'		=>	'Select whether you want your email address to be viewable to other users or not and if you want other users to be able to send you email via the forum (form email) or not.',
'Email setting 1'			=>	'Display your email address.',
'Email setting 2'			=>	'Hide your email address but allow form email.',
'Email setting 3'			=>	'Hide your email address and disallow form email.',
'Privacy options legend'	=>	'Set your privacy options',
'Confirm pass'				=>	'Confirm password',

'Username too short'		=>	'Usernames must be at least 2 characters long. Please choose another (longer) username.',
'Username too long'			=>	'Usernames must not be more than 25 characters long. Please choose another (shorter) username.',
'Username guest'			=>	'The username guest is reserved. Please choose another username.',
'Username IP'				=>	'Usernames may not be in the form of an IP address. Please choose another username.',
'Username reserved chars'	=>	'Usernames may not contain all the characters \', " and [ or ] at once. Please choose another username.',
'Username BBCode'			=>	'Usernames may not contain any of the text formatting tags (BBCode) that the forum uses. Please choose another username.',
'Banned username'			=>	'The username you entered is banned in this forum. Please choose another username.',
'Pass too short'			=>	'Passwords must be at least 4 characters long. Please choose another (longer) password.',
'Pass not match'			=>	'Passwords do not match.',
'Banned email'				=>	'The email address you entered is banned in this forum. Please choose another email address.',
'Dupe email'				=>	'Someone else is already registered with that email address. Please choose another email address.',
'Sig too long'				=>	'Signatures cannot be longer than %1$s characters. Please reduce your signature by %2$s characters.',
'Sig too many lines'		=>	'Signatures cannot have more than %s lines.',
'Bad ICQ'					=>	'You entered an invalid ICQ UIN. Please go back and correct.',

'UTC-12:00'					=>	'(UTC-12:00) International Date Line West',
'UTC-11:00'					=>	'(UTC-11:00) Niue, Samoa',
'UTC-10:00'					=>	'(UTC-10:00) Hawaii-Aleutian, Cook Island',
'UTC-09:30'					=>	'(UTC-09:30) Marquesas Islands',
'UTC-09:00'					=>	'(UTC-09:00) Alaska, Gambier Island',
'UTC-08:30'					=>	'(UTC-08:30) Pitcairn Islands',
'UTC-08:00'					=>	'(UTC-08:00) Pacific',
'UTC-07:00'					=>	'(UTC-07:00) Mountain',
'UTC-06:00'					=>	'(UTC-06:00) Central',
'UTC-05:00'					=>	'(UTC-05:00) Eastern',
'UTC-04:00'					=>	'(UTC-04:00) Atlantic',
'UTC-03:30'					=>	'(UTC-03:30) Newfoundland',
'UTC-03:00'					=>	'(UTC-03:00) Amazon, Central Greenland',
'UTC-02:00'					=>	'(UTC-02:00) Mid-Atlantic',
'UTC-01:00'					=>	'(UTC-01:00) Azores, Cape Verde, Eastern Greenland',
'UTC'						=>	'(UTC) Western European, Greenwich',
'UTC+01:00'					=>	'(UTC+01:00) Central European, West African',
'UTC+02:00'					=>	'(UTC+02:00) Eastern European, Central African',
'UTC+03:00'					=>	'(UTC+03:00) Eastern African',
'UTC+03:30'					=>	'(UTC+03:30) Iran',
'UTC+04:00'					=>	'(UTC+04:00) Moscow, Gulf, Samara',
'UTC+04:30'					=>	'(UTC+04:30) Afghanistan',
'UTC+05:00'					=>	'(UTC+05:00) Pakistan',
'UTC+05:30'					=>	'(UTC+05:30) India, Sri Lanka',
'UTC+05:45'					=>	'(UTC+05:45) Nepal',
'UTC+06:00'					=>	'(UTC+06:00) Bangladesh, Bhutan, Yekaterinburg',
'UTC+06:30'					=>	'(UTC+06:30) Cocos Islands, Myanmar',
'UTC+07:00'					=>	'(UTC+07:00) Indochina, Novosibirsk',
'UTC+08:00'					=>	'(UTC+08:00) Greater China, Australian Western, Krasnoyarsk',
'UTC+08:45'					=>	'(UTC+08:45) Southeastern Western Australia',
'UTC+09:00'					=>	'(UTC+09:00) Japan, Korea, Chita, Irkutsk',
'UTC+09:30'					=>	'(UTC+09:30) Australian Central',
'UTC+10:00'					=>	'(UTC+10:00) Australian Eastern',
'UTC+10:30'					=>	'(UTC+10:30) Lord Howe',
'UTC+11:00'					=>	'(UTC+11:00) Solomon Island, Vladivostok',
'UTC+11:30'					=>	'(UTC+11:30) Norfolk Island',
'UTC+12:00'					=>	'(UTC+12:00) New Zealand, Fiji, Magadan',
'UTC+12:45'					=>	'(UTC+12:45) Chatham Islands',
'UTC+13:00'					=>	'(UTC+13:00) Tonga, Phoenix Islands, Kamchatka',
'UTC+14:00'					=>	'(UTC+14:00) Line Islands'

);
